@@ -1,4 +1,4 @@
-#!/usr/bin/python26
+#!/usr/bin/python
 
 """Wrapper for zookeeper that manages watches.
 
@@ -58,7 +58,7 @@ class ZKWrapper(object):
 
   def _global_watch(self, zh, event, state, path):
     """Called when the connection to zookeeper has a state change."""
-    logging.debug('Global watch fired: %s %s %s' % (event, state, path))
+    logging.debug('Global watch fired: %s %s %s', event, state, path)
     if state == zookeeper.EXPIRED_SESSION_STATE:
       self._clientid = None
       self._connect()
@@ -70,7 +70,7 @@ class ZKWrapper(object):
         self._clientid = zookeeper.client_id(self._zookeeper)
         logging.debug('Registering watches to reestablish expired session')
         for path in self._watches.iterkeys():
-          logging.debug('Registering watch against: %s' % path)
+          logging.debug('Registering watch against: %s', path)
           h = self._handler_wrapper(path)
           zookeeper.aget(self._zookeeper, path, self._watcher, h)
 
@@ -88,7 +88,7 @@ class ZKWrapper(object):
       try:
         _, _, ips = socket.gethostbyname_ex(host)
         for ip in ips:
-          s.append('%s:%s' % (ip, port))
+          s.append('%s:%s'.format(ip, port))
       except socket.gaierror:
         logging.error('Hostname not known: %s', host)
       except socket.herror:
